@@ -17,7 +17,7 @@ with
     'WebService::DigitalOcean::Role::Regions',
     'WebService::DigitalOcean::Role::Sizes';
 
-our $VERSION = '0.020'; # VERSION
+our $VERSION = '0.021'; # VERSION
 
 has api_base_url => (
     is      => 'ro',
@@ -45,7 +45,7 @@ WebService::DigitalOcean - Access the DigitalOcean RESTful API (v2)
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 SYNOPSIS
 
@@ -91,7 +91,7 @@ L<< https://cloud.digitalocean.com/settings/applications >>.
 
 =head2 $do->domain_create(\%args)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -116,7 +116,7 @@ More info: L<< https://developers.digitalocean.com/#create-a-new-domain >>.
 
 =head2 $do->domain_delete($domain)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -134,7 +134,7 @@ More info: L<< https://developers.digitalocean.com/#delete-a-domain >>.
 
 =head2 $do->domain_get($domain)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -164,7 +164,7 @@ More info: L<< https://developers.digitalocean.com/#list-all-domains >>.
 
 =head2 $do->domain_record_create(\%args)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -213,7 +213,7 @@ More info: L<< https://developers.digitalocean.com/#create-a-new-domain-record >
 
 =head2 $do->domain_record_delete(\%args)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -238,7 +238,7 @@ More info: L<< https://developers.digitalocean.com/#delete-a-domain-record >>.
 
 =head2 $do->domain_record_get(\%args)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -265,7 +265,7 @@ More info: L<< https://developers.digitalocean.com/#retrieve-an-existing-domain-
 
 =head2 $do->domain_record_list($domain)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -287,7 +287,7 @@ More info: L<< https://developers.digitalocean.com/#list-all-domain-records >>.
 
 =head2 $do->droplet_create(\%args)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -299,6 +299,8 @@ More info: L<< https://developers.digitalocean.com/#list-all-domain-records >>.
 
 =item C<Str> $args{image}
 
+=item C<Str> $args{user_data} (optional)
+
 =item C<ArrayRef> $args{ssh_keys} (optional)
 
 =item C<Bool> $args{backups} (optional)
@@ -326,7 +328,7 @@ More info: L<< https://developers.digitalocean.com/#create-a-new-droplet >>.
 
 =head2 $do->droplet_delete($id)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -342,7 +344,7 @@ More info: L<< https://developers.digitalocean.com/#delete-a-droplet >>.
 
 =head2 $do->droplet_get($id)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -370,7 +372,7 @@ More info: L<< https://developers.digitalocean.com/#list-all-droplets >>.
 
 =head2 $do->droplet_resize(\%args)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -391,7 +393,7 @@ More info: L<< https://developers.digitalocean.com/#resize-a-droplet >>.
 
 =head2 $do->droplet_change_kernel(\%args)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -412,7 +414,7 @@ More info: L<< https://developers.digitalocean.com/#change-the-kernel >>.
 
 =head2 $do->droplet_rebuild(\%args)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -433,7 +435,7 @@ More info: L<< https://developers.digitalocean.com/#rebuild-a-droplet >>.
 
 =head2 $do->droplet_restore(\%args)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -454,7 +456,7 @@ More info: L<< https://developers.digitalocean.com/#restore-a-droplet >>.
 
 =head2 $do->droplet_rename(\%args)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -475,7 +477,7 @@ More info: L<< https://developers.digitalocean.com/#rename-a-droplet >>.
 
 =head2 $do->droplet_snapshot(\%args)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -496,7 +498,7 @@ More info: L<< https://developers.digitalocean.com/#rebuild-a-droplet >>.
 
 =head2 $do->droplet_reboot($droplet_id)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -512,7 +514,7 @@ More info: L<< https://developers.digitalocean.com/#reboot-a-droplet >>.
 
 =head2 $do->droplet_power_cycle($droplet_id)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -528,7 +530,7 @@ More info: L<< https://developers.digitalocean.com/#power-cycle-a-droplet >>.
 
 =head2 $do->droplet_power_on($droplet_id)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -544,7 +546,7 @@ More info: L<< https://developers.digitalocean.com/#power-on-a-droplet >>.
 
 =head2 $do->droplet_power_off($droplet_id)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -560,7 +562,7 @@ More info: L<< https://developers.digitalocean.com/#power-off-a-droplet >>.
 
 =head2 $do->droplet_password_reset($droplet_id)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -576,7 +578,7 @@ More info: L<< https://developers.digitalocean.com/#password-reset-a-droplet >>.
 
 =head2 $do->droplet_shutdown($droplet_id)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -592,7 +594,7 @@ More info: L<< https://developers.digitalocean.com/#shutdown-a-droplet >>.
 
 =head2 $do->droplet_enable_ipv6($droplet_id)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -608,7 +610,7 @@ More info: L<< https://developers.digitalocean.com/#enable-ipv6 >>.
 
 =head2 $do->droplet_enable_private_networking($droplet_id)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -624,7 +626,7 @@ More info: L<< https://developers.digitalocean.com/#enable-private-networking >>
 
 =head2 $do->droplet_disable_backups($droplet_id)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -640,7 +642,7 @@ More info: L<< https://developers.digitalocean.com/#disable-backups >>.
 
 =head2 $do->droplet_action_get(\%args)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -661,7 +663,7 @@ More info: L<< https://developers.digitalocean.com/#retrieve-a-droplet-action >>
 
 =head2 $do->key_create(\%args)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -682,7 +684,7 @@ More info: L<< https://developers.digitalocean.com/#create-a-new-key >>.
 
 =head2 $do->key_delete(\%args)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -700,7 +702,7 @@ More info: L<< https://developers.digitalocean.com/#destroy-a-key >>.
 
 =head2 $do->key_get(\%args)
 
-=head3 Arguments
+B<Arguments:>
 
 =over
 
@@ -778,7 +780,7 @@ André Walker <andre@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by André Walker.
+This software is Copyright (c) 2015 by André Walker.
 
 This is free software, licensed under:
 
